************
Installation
************


Prerequisites
=============

Quantities has a few dependencies:

* Python_ (>=3.8)
* NumPy_ (>=1.19)

(bearing in mind that not all combinations of Python and NumPy versions necessarily work).


Source Code Installation
========================

To install Quantities, run "pip install quantities".


Development
===========

You can follow and contribute to Quantities' development using git::

  git clone git@github.com:python-quantities/python-quantities.git

Bugs, feature requests, and questions can be directed to the GitHub_
website.


.. _Python: http://www.python.org/
.. _NumPy: http://www.scipy.org
.. _PyPI: http://pypi.python.org/pypi/quantities
.. _GitHub: http://github.com/python-quantities/python-quantities
